from ..broker import Broker


class DeviceFlowFilterCfgBroker(Broker):
    controller = "device_flow_filter_cfgs"

    def show(self, **kwargs):
        """Shows the details for the specified device flow filter cfg.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device flow filter cfg methods. The listed methods will be called on each device flow filter cfg returned and included in the output. Available methods are: src_device_zone, dest_device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: src_device_zone, dest_device_zone, data_source, device.
             :type include: Array of String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_flow_filter_cfg: The device flow filter cfg identified by the specified DeviceFlowFilterCfgID.
             :rtype device_flow_filter_cfg: DeviceFlowFilterCfg

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available device flow filter cfgs. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device flow filter cfgs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device flow filter cfg methods. The listed methods will be called on each device flow filter cfg returned and included in the output. Available methods are: src_device_zone, dest_device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: src_device_zone, dest_device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFlowFilterCfgID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFlowFilterCfgID. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFlowFilterCfg. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_flow_filter_cfgs: An array of the DeviceFlowFilterCfg objects that match the specified input criteria.
             :rtype device_flow_filter_cfgs: Array of DeviceFlowFilterCfg

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available device flow filter cfgs matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record.
             :type DataSourceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DestDeviceZoneID: The internal NetMRI identifier of the Zone that is destination point for this ip packet flow definition.
             :type DestDeviceZoneID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceID: The internal NetMRI identifier for the device to which belongs this ip packet flow definition
             :type DeviceID: Array of Integer

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcChangedCols: The fields that changed between this revision of the record and the previous revision.
             :type FfcChangedCols: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcConfigText: The text that was defined in the configuration for this ip packet flow definition.
             :type FfcConfigText: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcData: Extra data for this usage of the rulelist. May depend on the vendor implementation.
             :type FfcData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcDisplayText: The associated text for display.
             :type FfcDisplayText: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcEndTime: The ending effective time of this record, or empty if still in effect.
             :type FfcEndTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcFirstSeenTime: The timestamp of when NetMRI saw for the first time this ip packet flow definition
             :type FfcFirstSeenTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcName: The name associated with this usage of the rulelist.
             :type FfcName: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcProvisionData: Internal data - do not modify, may change without warning.
             :type FfcProvisionData: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcStartTime: The starting effective time of this record.
             :type FfcStartTime: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcTimestamp: The date and time this record was collected or calculated.
             :type FfcTimestamp: Array of DateTime

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param FfcType: The type of operation applied on this ip packet flow definition. One of : 'filter', 'nat', 'vpn',
             :type FfcType: Array of String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SrcDeviceZoneID: The internal NetMRI identifier of the Zone that is source point for this ip packet flow definition
             :type SrcDeviceZoneID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device flow filter cfgs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device flow filter cfg methods. The listed methods will be called on each device flow filter cfg returned and included in the output. Available methods are: src_device_zone, dest_device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: src_device_zone, dest_device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFlowFilterCfgID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFlowFilterCfgID. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFlowFilterCfg. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against device flow filter cfgs, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: DataSourceID, DestDeviceZoneID, DeviceFlowFilterCfgID, DeviceID, FfcChangedCols, FfcConfigText, FfcData, FfcDisplayText, FfcEndTime, FfcFirstSeenTime, FfcName, FfcProvisionData, FfcStartTime, FfcTimestamp, FfcType, SrcDeviceZoneID.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_flow_filter_cfgs: An array of the DeviceFlowFilterCfg objects that match the specified input criteria.
             :rtype device_flow_filter_cfgs: Array of DeviceFlowFilterCfg

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available device flow filter cfgs matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: DataSourceID, DestDeviceZoneID, DeviceFlowFilterCfgID, DeviceID, FfcChangedCols, FfcConfigText, FfcData, FfcDisplayText, FfcEndTime, FfcFirstSeenTime, FfcName, FfcProvisionData, FfcStartTime, FfcTimestamp, FfcType, SrcDeviceZoneID.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DataSourceID: The operator to apply to the field DataSourceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DataSourceID: The internal NetMRI identifier for the collector NetMRI that collected this data record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DataSourceID: If op_DataSourceID is specified, the field named in this input will be compared to the value in DataSourceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_f_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DataSourceID: If op_DataSourceID is specified, this value will be compared to the value in DataSourceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DataSourceID must be specified if op_DataSourceID is specified.
             :type val_c_DataSourceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DestDeviceZoneID: The operator to apply to the field DestDeviceZoneID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DestDeviceZoneID: The internal NetMRI identifier of the Zone that is destination point for this ip packet flow definition. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DestDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DestDeviceZoneID: If op_DestDeviceZoneID is specified, the field named in this input will be compared to the value in DestDeviceZoneID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DestDeviceZoneID must be specified if op_DestDeviceZoneID is specified.
             :type val_f_DestDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DestDeviceZoneID: If op_DestDeviceZoneID is specified, this value will be compared to the value in DestDeviceZoneID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DestDeviceZoneID must be specified if op_DestDeviceZoneID is specified.
             :type val_c_DestDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceFlowFilterCfgID: The operator to apply to the field DeviceFlowFilterCfgID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceFlowFilterCfgID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceFlowFilterCfgID: If op_DeviceFlowFilterCfgID is specified, the field named in this input will be compared to the value in DeviceFlowFilterCfgID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceFlowFilterCfgID must be specified if op_DeviceFlowFilterCfgID is specified.
             :type val_f_DeviceFlowFilterCfgID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceFlowFilterCfgID: If op_DeviceFlowFilterCfgID is specified, this value will be compared to the value in DeviceFlowFilterCfgID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceFlowFilterCfgID must be specified if op_DeviceFlowFilterCfgID is specified.
             :type val_c_DeviceFlowFilterCfgID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceID: The operator to apply to the field DeviceID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. DeviceID: The internal NetMRI identifier for the device to which belongs this ip packet flow definition For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_DeviceID: If op_DeviceID is specified, the field named in this input will be compared to the value in DeviceID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_DeviceID must be specified if op_DeviceID is specified.
             :type val_f_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceID: If op_DeviceID is specified, this value will be compared to the value in DeviceID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_DeviceID must be specified if op_DeviceID is specified.
             :type val_c_DeviceID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcChangedCols: The operator to apply to the field FfcChangedCols. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcChangedCols: The fields that changed between this revision of the record and the previous revision. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcChangedCols: If op_FfcChangedCols is specified, the field named in this input will be compared to the value in FfcChangedCols using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcChangedCols must be specified if op_FfcChangedCols is specified.
             :type val_f_FfcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcChangedCols: If op_FfcChangedCols is specified, this value will be compared to the value in FfcChangedCols using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcChangedCols must be specified if op_FfcChangedCols is specified.
             :type val_c_FfcChangedCols: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcConfigText: The operator to apply to the field FfcConfigText. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcConfigText: The text that was defined in the configuration for this ip packet flow definition. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcConfigText: If op_FfcConfigText is specified, the field named in this input will be compared to the value in FfcConfigText using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcConfigText must be specified if op_FfcConfigText is specified.
             :type val_f_FfcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcConfigText: If op_FfcConfigText is specified, this value will be compared to the value in FfcConfigText using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcConfigText must be specified if op_FfcConfigText is specified.
             :type val_c_FfcConfigText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcData: The operator to apply to the field FfcData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcData: Extra data for this usage of the rulelist. May depend on the vendor implementation. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcData: If op_FfcData is specified, the field named in this input will be compared to the value in FfcData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcData must be specified if op_FfcData is specified.
             :type val_f_FfcData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcData: If op_FfcData is specified, this value will be compared to the value in FfcData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcData must be specified if op_FfcData is specified.
             :type val_c_FfcData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcDisplayText: The operator to apply to the field FfcDisplayText. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcDisplayText: The associated text for display. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcDisplayText: If op_FfcDisplayText is specified, the field named in this input will be compared to the value in FfcDisplayText using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcDisplayText must be specified if op_FfcDisplayText is specified.
             :type val_f_FfcDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcDisplayText: If op_FfcDisplayText is specified, this value will be compared to the value in FfcDisplayText using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcDisplayText must be specified if op_FfcDisplayText is specified.
             :type val_c_FfcDisplayText: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcEndTime: The operator to apply to the field FfcEndTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcEndTime: The ending effective time of this record, or empty if still in effect. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcEndTime: If op_FfcEndTime is specified, the field named in this input will be compared to the value in FfcEndTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcEndTime must be specified if op_FfcEndTime is specified.
             :type val_f_FfcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcEndTime: If op_FfcEndTime is specified, this value will be compared to the value in FfcEndTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcEndTime must be specified if op_FfcEndTime is specified.
             :type val_c_FfcEndTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcFirstSeenTime: The operator to apply to the field FfcFirstSeenTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcFirstSeenTime: The timestamp of when NetMRI saw for the first time this ip packet flow definition For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcFirstSeenTime: If op_FfcFirstSeenTime is specified, the field named in this input will be compared to the value in FfcFirstSeenTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcFirstSeenTime must be specified if op_FfcFirstSeenTime is specified.
             :type val_f_FfcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcFirstSeenTime: If op_FfcFirstSeenTime is specified, this value will be compared to the value in FfcFirstSeenTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcFirstSeenTime must be specified if op_FfcFirstSeenTime is specified.
             :type val_c_FfcFirstSeenTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcName: The operator to apply to the field FfcName. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcName: The name associated with this usage of the rulelist. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcName: If op_FfcName is specified, the field named in this input will be compared to the value in FfcName using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcName must be specified if op_FfcName is specified.
             :type val_f_FfcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcName: If op_FfcName is specified, this value will be compared to the value in FfcName using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcName must be specified if op_FfcName is specified.
             :type val_c_FfcName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcProvisionData: The operator to apply to the field FfcProvisionData. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcProvisionData: Internal data - do not modify, may change without warning. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcProvisionData: If op_FfcProvisionData is specified, the field named in this input will be compared to the value in FfcProvisionData using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcProvisionData must be specified if op_FfcProvisionData is specified.
             :type val_f_FfcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcProvisionData: If op_FfcProvisionData is specified, this value will be compared to the value in FfcProvisionData using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcProvisionData must be specified if op_FfcProvisionData is specified.
             :type val_c_FfcProvisionData: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcStartTime: The operator to apply to the field FfcStartTime. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcStartTime: The starting effective time of this record. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcStartTime: If op_FfcStartTime is specified, the field named in this input will be compared to the value in FfcStartTime using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcStartTime must be specified if op_FfcStartTime is specified.
             :type val_f_FfcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcStartTime: If op_FfcStartTime is specified, this value will be compared to the value in FfcStartTime using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcStartTime must be specified if op_FfcStartTime is specified.
             :type val_c_FfcStartTime: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcTimestamp: The operator to apply to the field FfcTimestamp. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcTimestamp: The date and time this record was collected or calculated. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcTimestamp: If op_FfcTimestamp is specified, the field named in this input will be compared to the value in FfcTimestamp using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcTimestamp must be specified if op_FfcTimestamp is specified.
             :type val_f_FfcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcTimestamp: If op_FfcTimestamp is specified, this value will be compared to the value in FfcTimestamp using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcTimestamp must be specified if op_FfcTimestamp is specified.
             :type val_c_FfcTimestamp: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_FfcType: The operator to apply to the field FfcType. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. FfcType: The type of operation applied on this ip packet flow definition. One of : 'filter', 'nat', 'vpn',  For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_FfcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_FfcType: If op_FfcType is specified, the field named in this input will be compared to the value in FfcType using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_FfcType must be specified if op_FfcType is specified.
             :type val_f_FfcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_FfcType: If op_FfcType is specified, this value will be compared to the value in FfcType using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_FfcType must be specified if op_FfcType is specified.
             :type val_c_FfcType: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_SrcDeviceZoneID: The operator to apply to the field SrcDeviceZoneID. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. SrcDeviceZoneID: The internal NetMRI identifier of the Zone that is source point for this ip packet flow definition For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_SrcDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_SrcDeviceZoneID: If op_SrcDeviceZoneID is specified, the field named in this input will be compared to the value in SrcDeviceZoneID using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_SrcDeviceZoneID must be specified if op_SrcDeviceZoneID is specified.
             :type val_f_SrcDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_SrcDeviceZoneID: If op_SrcDeviceZoneID is specified, this value will be compared to the value in SrcDeviceZoneID using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_SrcDeviceZoneID must be specified if op_SrcDeviceZoneID is specified.
             :type val_c_SrcDeviceZoneID: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param DeviceGroupID: The internal NetMRI identifier of the device groups to which to limit the results.
             :type DeviceGroupID: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param timestamp: The data returned will represent the device flow filter cfgs as of this date and time. If omitted, the result will indicate the most recently collected data.
             :type timestamp: DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param methods: A list of device flow filter cfg methods. The listed methods will be called on each device flow filter cfg returned and included in the output. Available methods are: src_device_zone, dest_device_zone, data_source, device.
             :type methods: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param include: A list of associated object types to include in the output. The listed associations will be returned as outputs named according to the association name (see outputs below). Available includes are: src_device_zone, dest_device_zone, data_source, device.
             :type include: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` DeviceFlowFilterCfgID

             :param sort: The data field(s) to use for sorting the output. Default is DeviceFlowFilterCfgID. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each DeviceFlowFilterCfg. Valid values are DeviceFlowFilterCfgID, DeviceID, DataSourceID, FfcName, FfcData, FfcFirstSeenTime, FfcStartTime, FfcEndTime, FfcTimestamp, FfcChangedCols, SrcDeviceZoneID, DestDeviceZoneID, FfcType, FfcDisplayText, FfcConfigText, FfcProvisionData. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return device_flow_filter_cfgs: An array of the DeviceFlowFilterCfg objects that match the specified input criteria.
             :rtype device_flow_filter_cfgs: Array of DeviceFlowFilterCfg

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def src_device_zone(self, **kwargs):
        """The DeviceZone that is source point for this ip packet flow definition.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The DeviceZone that is source point for this ip packet flow definition.
             :rtype : DeviceZone

            """

        return self.api_request(self._get_method_fullname("src_device_zone"), kwargs)

    def dest_device_zone(self, **kwargs):
        """The DeviceZone that is destination point for this ip packet flow definition.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The DeviceZone that is destination point for this ip packet flow definition.
             :rtype : DeviceZone

            """

        return self.api_request(self._get_method_fullname("dest_device_zone"), kwargs)

    def device(self, **kwargs):
        """The device from which this data was collected.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The device from which this data was collected.
             :rtype : Device

            """

        return self.api_request(self._get_method_fullname("device"), kwargs)

    def data_source(self, **kwargs):
        """The collector NetMRI that collected this data record.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceFlowFilterCfgID: The internal NetMRI identifier for this ip packet flow definition.
             :type DeviceFlowFilterCfgID: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return : The collector NetMRI that collected this data record.
             :rtype : DataSource

            """

        return self.api_request(self._get_method_fullname("data_source"), kwargs)



from ..broker import Broker


class SnmpMibBroker(Broker):
    controller = "snmp_mibs"

    def delete(self, **kwargs):
        """Delete a MIB specified by name

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param name: Unique MIB name
             :type name: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The id of the output file
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param read: The number of bytes to read from the delete output
             :type read: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("delete"), kwargs)

    def import_data(self, **kwargs):
        """Import MIB in bulk via file

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param file: MIB file contents to be imported
             :type file: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The id of the output file
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param read: The number of bytes to read from the import output
             :type read: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("import"), kwargs)

    def export(self, **kwargs):
        """Export MIB via file

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param name: MIB file name to be exported
             :type name: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("export"), kwargs)



from ..broker import Broker


class AuthServerBroker(Broker):
    controller = "auth_servers"

    def show(self, **kwargs):
        """Shows the details for the specified auth server.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_server: The auth server identified by the specified id.
             :rtype auth_server: AuthServer

            """

        return self.api_request(self._get_method_fullname("show"), kwargs)

    def index(self, **kwargs):
        """Lists the available auth servers. Any of the inputs listed may be be used to narrow the list; other inputs will be ignored. Of the various ways to query lists, using this method is most efficient.

            **Inputs**

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_service_id: The id of the authentication service, this server is member of.
             :type auth_service_id: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Array of Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each AuthServer. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_servers: An array of the AuthServer objects that match the specified input criteria.
             :rtype auth_servers: Array of AuthServer

            """

        return self.api_list_request(self._get_method_fullname("index"), kwargs)

    def search(self, **kwargs):
        """Lists the available auth servers matching the input criteria. This method provides a more flexible search interface than the index method, but searching using this method is more demanding on the system and will not perform to the same level as the index method. The input fields listed below will be used as in the index method, to filter the result, along with the optional query string and XML filter described below.

            **Inputs**

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_cert: The SSL certificate of an Authentication Server. (Required for Active Directory method).
             :type auth_cert: Array of String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_encryption: The Encryption method (none or SSL) (required for Active Directory method).
             :type auth_encryption: Array of String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_port: Authentication Port (required for Active Directory method).
             :type auth_port: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_protocol: The password exchange protocol to use for authentication. One of (PAP, CHAP)
             :type auth_protocol: Array of String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_server: Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods).
             :type auth_server: Array of String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_service_id: The id of the authentication service, this server is member of.
             :type auth_service_id: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_shared_secret: The shared secret of an authentication server (required for Radius and Tacacs methods).
             :type auth_shared_secret: Array of String

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_version: The version use for the authentication (LDAP).
             :type auth_version: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param created_at: The date and time the record was initially created in NetMRI.
             :type created_at: Array of DateTime

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param enabled_ind: A flag indicating whether the authentication server settings is enabled or disabled.
             :type enabled_ind: Array of Boolean

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param priority: Priority assigned to an authentication server.
             :type priority: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param secure_version: Internal encrypt version used for any auth_shared_secret
             :type secure_version: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param source_interface_id: The NetMRI interface to use as source of the packets sent to the authentication server.
             :type source_interface_id: Array of Integer

            |  ``api version min:`` 2.5
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param updated_at: The date and time the record was last modified in NetMRI.
             :type updated_at: Array of DateTime

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each AuthServer. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: This value will be matched against auth servers, looking to see if one or more of the listed attributes contain the passed value. You may also surround the value with '/' and '/' to perform a regular expression search rather than a containment operation. Any record that matches will be returned. The attributes searched are: auth_cert, auth_encryption, auth_port, auth_protocol, auth_server, auth_service_id, auth_shared_secret, auth_version, created_at, enabled_ind, id, priority, secure_version, source_interface_id, updated_at.
             :type query: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_servers: An array of the AuthServer objects that match the specified input criteria.
             :rtype auth_servers: Array of AuthServer

            """

        return self.api_list_request(self._get_method_fullname("search"), kwargs)

    def find(self, **kwargs):
        """Lists the available auth servers matching the input specification. This provides the most flexible search specification of all the query mechanisms, enabling searching using comparison operations other than equality. However, it is more complex to use and will not perform as efficiently as the index or search methods. In the input descriptions below, 'field names' refers to the following fields: auth_cert, auth_encryption, auth_port, auth_protocol, auth_server, auth_service_id, auth_shared_secret, auth_version, created_at, enabled_ind, id, priority, secure_version, source_interface_id, updated_at.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_cert: The operator to apply to the field auth_cert. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_cert: The SSL certificate of an Authentication Server. (Required for Active Directory method). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_cert: If op_auth_cert is specified, the field named in this input will be compared to the value in auth_cert using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_cert must be specified if op_auth_cert is specified.
             :type val_f_auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_cert: If op_auth_cert is specified, this value will be compared to the value in auth_cert using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_cert must be specified if op_auth_cert is specified.
             :type val_c_auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_encryption: The operator to apply to the field auth_encryption. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_encryption: The Encryption method (none or SSL) (required for Active Directory method). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_encryption: If op_auth_encryption is specified, the field named in this input will be compared to the value in auth_encryption using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_encryption must be specified if op_auth_encryption is specified.
             :type val_f_auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_encryption: If op_auth_encryption is specified, this value will be compared to the value in auth_encryption using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_encryption must be specified if op_auth_encryption is specified.
             :type val_c_auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_port: The operator to apply to the field auth_port. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_port: Authentication Port (required for Active Directory method). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_port: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_port: If op_auth_port is specified, the field named in this input will be compared to the value in auth_port using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_port must be specified if op_auth_port is specified.
             :type val_f_auth_port: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_port: If op_auth_port is specified, this value will be compared to the value in auth_port using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_port must be specified if op_auth_port is specified.
             :type val_c_auth_port: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_protocol: The operator to apply to the field auth_protocol. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_protocol: The password exchange protocol to use for authentication. One of (PAP, CHAP) For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_protocol: If op_auth_protocol is specified, the field named in this input will be compared to the value in auth_protocol using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_protocol must be specified if op_auth_protocol is specified.
             :type val_f_auth_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_protocol: If op_auth_protocol is specified, this value will be compared to the value in auth_protocol using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_protocol must be specified if op_auth_protocol is specified.
             :type val_c_auth_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_server: The operator to apply to the field auth_server. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_server: Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_server: If op_auth_server is specified, the field named in this input will be compared to the value in auth_server using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_server must be specified if op_auth_server is specified.
             :type val_f_auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_server: If op_auth_server is specified, this value will be compared to the value in auth_server using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_server must be specified if op_auth_server is specified.
             :type val_c_auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_service_id: The operator to apply to the field auth_service_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_service_id: The id of the authentication service, this server is member of. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_service_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_service_id: If op_auth_service_id is specified, the field named in this input will be compared to the value in auth_service_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_service_id must be specified if op_auth_service_id is specified.
             :type val_f_auth_service_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_service_id: If op_auth_service_id is specified, this value will be compared to the value in auth_service_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_service_id must be specified if op_auth_service_id is specified.
             :type val_c_auth_service_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_shared_secret: The operator to apply to the field auth_shared_secret. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_shared_secret: The shared secret of an authentication server (required for Radius and Tacacs methods). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_shared_secret: If op_auth_shared_secret is specified, the field named in this input will be compared to the value in auth_shared_secret using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_shared_secret must be specified if op_auth_shared_secret is specified.
             :type val_f_auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_shared_secret: If op_auth_shared_secret is specified, this value will be compared to the value in auth_shared_secret using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_shared_secret must be specified if op_auth_shared_secret is specified.
             :type val_c_auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_auth_version: The operator to apply to the field auth_version. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. auth_version: The version use for the authentication (LDAP). For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_auth_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_auth_version: If op_auth_version is specified, the field named in this input will be compared to the value in auth_version using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_auth_version must be specified if op_auth_version is specified.
             :type val_f_auth_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_auth_version: If op_auth_version is specified, this value will be compared to the value in auth_version using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_auth_version must be specified if op_auth_version is specified.
             :type val_c_auth_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_created_at: The operator to apply to the field created_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. created_at: The date and time the record was initially created in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_created_at: If op_created_at is specified, the field named in this input will be compared to the value in created_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_created_at must be specified if op_created_at is specified.
             :type val_f_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_created_at: If op_created_at is specified, this value will be compared to the value in created_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_created_at must be specified if op_created_at is specified.
             :type val_c_created_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_enabled_ind: The operator to apply to the field enabled_ind. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. enabled_ind: A flag indicating whether the authentication server settings is enabled or disabled. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_enabled_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_enabled_ind: If op_enabled_ind is specified, the field named in this input will be compared to the value in enabled_ind using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_enabled_ind must be specified if op_enabled_ind is specified.
             :type val_f_enabled_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_enabled_ind: If op_enabled_ind is specified, this value will be compared to the value in enabled_ind using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_enabled_ind must be specified if op_enabled_ind is specified.
             :type val_c_enabled_ind: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_id: The operator to apply to the field id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. id: The authentication server identifier. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_id: If op_id is specified, the field named in this input will be compared to the value in id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_id must be specified if op_id is specified.
             :type val_f_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_id: If op_id is specified, this value will be compared to the value in id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_id must be specified if op_id is specified.
             :type val_c_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_priority: The operator to apply to the field priority. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. priority: Priority assigned to an authentication server. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_priority: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_priority: If op_priority is specified, the field named in this input will be compared to the value in priority using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_priority must be specified if op_priority is specified.
             :type val_f_priority: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_priority: If op_priority is specified, this value will be compared to the value in priority using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_priority must be specified if op_priority is specified.
             :type val_c_priority: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_secure_version: The operator to apply to the field secure_version. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. secure_version: Internal encrypt version used for any auth_shared_secret For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_secure_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_secure_version: If op_secure_version is specified, the field named in this input will be compared to the value in secure_version using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_secure_version must be specified if op_secure_version is specified.
             :type val_f_secure_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_secure_version: If op_secure_version is specified, this value will be compared to the value in secure_version using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_secure_version must be specified if op_secure_version is specified.
             :type val_c_secure_version: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_source_interface_id: The operator to apply to the field source_interface_id. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. source_interface_id: The NetMRI interface to use as source of the packets sent to the authentication server. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_source_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_source_interface_id: If op_source_interface_id is specified, the field named in this input will be compared to the value in source_interface_id using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_source_interface_id must be specified if op_source_interface_id is specified.
             :type val_f_source_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_source_interface_id: If op_source_interface_id is specified, this value will be compared to the value in source_interface_id using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_source_interface_id must be specified if op_source_interface_id is specified.
             :type val_c_source_interface_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_updated_at: The operator to apply to the field updated_at. Valid values are: =, <>, rlike, not rlike, >, >=, <, <=, like, not like, is null, is not null, between. updated_at: The date and time the record was last modified in NetMRI. For the between operator the value will be treated as an Array if comma delimited string is passed, and it must contain an even number of values.
             :type op_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_f_updated_at: If op_updated_at is specified, the field named in this input will be compared to the value in updated_at using the specified operator. That is, the value in this input will be treated as another field name, rather than a constant value. Either this field or val_c_updated_at must be specified if op_updated_at is specified.
             :type val_f_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_updated_at: If op_updated_at is specified, this value will be compared to the value in updated_at using the specified operator. The value in this input will be treated as an explicit constant value. Either this field or val_f_updated_at must be specified if op_updated_at is specified.
             :type val_c_updated_at: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The record number to return in the selected page of data. It will always appear, although it may not be the first record. See the :limit for more information.
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1000

             :param limit: The size of the page of data, that is, the maximum number of records returned. The limit size will be used to break the data up into pages and the first page with the start record will be returned. So if you have 100 records and use a :limit of 10 and a :start of 10, you will get records 10-19. The maximum limit is 10000.
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` id

             :param sort: The data field(s) to use for sorting the output. Default is id. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version.
             :type sort: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` asc

             :param dir: The direction(s) in which to sort the data. Default is 'asc'. Valid values are 'asc' and 'desc'.
             :type dir: Array of String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of attributes to return for each AuthServer. Valid values are id, priority, enabled_ind, auth_server, auth_port, auth_shared_secret, auth_encryption, auth_cert, created_at, updated_at, secure_version, auth_service_id, auth_protocol, source_interface_id, auth_version. If empty or omitted, all attributes will be returned.
             :type select: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_field: The field name for NIOS GOTO that is used for locating a row position of records.
             :type goto_field: String

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param goto_value: The value of goto_field for NIOS GOTO that is used for locating a row position of records.
             :type goto_value: String

            |  ``api version min:`` 2.3
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit and pagination will be enforced after the filter. Remind that this kind of filter may be costly and inefficient if not associated with a database filtering.
             :type xml_filter: String

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_servers: An array of the AuthServer objects that match the specified input criteria.
             :rtype auth_servers: Array of AuthServer

            """

        return self.api_list_request(self._get_method_fullname("find"), kwargs)

    def create(self, **kwargs):
        """Creates a new auth server.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_cert: The SSL certificate of an Authentication Server. (Required for Active Directory method).
             :type auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_encryption: The Encryption method (none or SSL) (required for Active Directory method).
             :type auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_port: Authentication Port (required for Active Directory method).
             :type auth_port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param auth_server: Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods).
             :type auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param auth_service_id: The id of the authentication service, this server is member of.
             :type auth_service_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_shared_secret: The shared secret of an authentication server (required for Radius and Tacacs methods).
             :type auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_version: The version use for the authentication (LDAP).
             :type auth_version: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` True

             :param enabled_ind: A flag indicating whether the authentication server settings is enabled or disabled.
             :type enabled_ind: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 1

             :param priority: Priority assigned to an authentication server.
             :type priority: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param source_interface_id: The NetMRI interface to use as source of the packets sent to the authentication server.
             :type source_interface_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The id of the newly created auth server.
             :rtype id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return model: The class name of the newly created auth server.
             :rtype model: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return uri: A URI that may be used to retrieve the newly created auth server.
             :rtype uri: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_server: The newly created auth server.
             :rtype auth_server: AuthServer

            """

        return self.api_request(self._get_method_fullname("create"), kwargs)

    def update(self, **kwargs):
        """Updates an existing auth server.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_cert: The SSL certificate of an Authentication Server. (Required for Active Directory method). If omitted, this field will not be updated.
             :type auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_encryption: The Encryption method (none or SSL) (required for Active Directory method). If omitted, this field will not be updated.
             :type auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_port: Authentication Port (required for Active Directory method). If omitted, this field will not be updated.
             :type auth_port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_protocol: The password exchange protocol to use for authentication. One of (PAP, CHAP) If omitted, this field will not be updated.
             :type auth_protocol: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_server: Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods). If omitted, this field will not be updated.
             :type auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_service_id: The id of the authentication service, this server is member of. If omitted, this field will not be updated.
             :type auth_service_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_shared_secret: The shared secret of an authentication server (required for Radius and Tacacs methods). If omitted, this field will not be updated.
             :type auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_version: The version use for the authentication (LDAP). If omitted, this field will not be updated.
             :type auth_version: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` True

             :param enabled_ind: A flag indicating whether the authentication server settings is enabled or disabled. If omitted, this field will be updated to the default value.
             :type enabled_ind: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param priority: Priority assigned to an authentication server. If omitted, this field will not be updated.
             :type priority: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param source_interface_id: The NetMRI interface to use as source of the packets sent to the authentication server. If omitted, this field will not be updated.
             :type source_interface_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The id of the updated auth server.
             :rtype id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return model: The class name of the updated auth server.
             :rtype model: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return uri: A URI that may be used to retrieve the updated auth server.
             :rtype uri: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_server: The updated auth server.
             :rtype auth_server: AuthServer

            """

        return self.api_request(self._get_method_fullname("update"), kwargs)

    def destroy(self, **kwargs):
        """Deletes the specified auth server from NetMRI.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("destroy"), kwargs)

    def add_or_update_auth_server(self, **kwargs):
        """Creates a new auth server.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_cert: The SSL certificate of an Authentication Server. (Required for Active Directory method).
             :type auth_cert: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_encryption: The Encryption method (none or SSL) (required for Active Directory method).
             :type auth_encryption: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_port: Authentication Port (required for Active Directory method).
             :type auth_port: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_server: Authentication Server Name (required for Radius, Tacacs, LDAP and Active Directory methods).
             :type auth_server: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param auth_service_id: The id of the authentication service, this server is member of.
             :type auth_service_id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_shared_secret: The shared secret of an authentication server (required for Radius and Tacacs methods).
             :type auth_shared_secret: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param auth_version: The version use for the authentication (LDAP).
             :type auth_version: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` True

             :param enabled_ind: A flag indicating whether the authentication server settings is enabled or disabled.
             :type enabled_ind: Boolean

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The authentication server identifier.
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param priority: Priority assigned to an authentication server.
             :type priority: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param source_interface_id: The NetMRI interface to use as source of the packets sent to the authentication server.
             :type source_interface_id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return id: The id of the newly created auth server.
             :rtype id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return model: The class name of the newly created auth server.
             :rtype model: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return uri: A URI that may be used to retrieve the newly created auth server.
             :rtype uri: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_server: The newly created auth server.
             :rtype auth_server: AuthServer

            """

        return self.api_request(self._get_method_fullname("add_or_update_auth_server"), kwargs)

    def duplicate(self, **kwargs):
        """Duplicate an authentication server.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The internal NetMRI identifier for the authentication server.
             :type id: Integer

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return server_id: The new authentication server id.
             :rtype server_id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return auth_server: Authentication Server ip.
             :rtype auth_server: String

            """

        return self.api_request(self._get_method_fullname("duplicate"), kwargs)

    def del_auth_server(self, **kwargs):
        """Remove a given server from the specified Authentication Service

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: The id of the authentication server to be removed
             :type id: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param service_id: The id of the authentication service to modify
             :type service_id: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("del_auth_server"), kwargs)



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class DeviceIpRangeRemote(RemoteModel):
    """
    Network IP Ranges definition


    |  ``DeviceIPRangeID:`` The internal NetMRI identifier for ip address range definition.
    |  ``attribute type:`` number

    |  ``DeviceID:`` The internal NetMRI identifier for the device to which belongs this flow.
    |  ``attribute type:`` number

    |  ``DeviceObjectID:`` The internal NetMRI identifier for the service to which belongs this flow.
    |  ``attribute type:`` number

    |  ``IprFirstSeenTime:`` The timestamp of when NetMRI saw for the first time this flow.
    |  ``attribute type:`` datetime

    |  ``IprIPVersion:`` The ip version for this range. 4 or 6.
    |  ``attribute type:`` number

    |  ``IprDisplayText:`` The text that was defined in the configuration for this ip address range.
    |  ``attribute type:`` string

    |  ``IprIPNumericMin:`` The numeric value for the range min value.
    |  ``attribute type:`` number

    |  ``IprIPNumericMax:`` The numeric value for the range max value.
    |  ``attribute type:`` number




    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number


    |  ``IprStartTime:`` The starting effective time of this record.
    |  ``attribute type:`` datetime

    |  ``IprEndTime:`` The ending effective time of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``IprTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``IprChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    """

    properties = ("DeviceIPRangeID",
                  "DeviceID",
                  "DeviceObjectID",
                  "IprFirstSeenTime",
                  "IprIPVersion",
                  "IprDisplayText",
                  "IprIPNumericMin",
                  "IprIPNumericMax",
                  "DataSourceID",
                  "IprStartTime",
                  "IprEndTime",
                  "IprTimestamp",
                  "IprChangedCols",
                  )

    @property
    @check_api_availability
    def device_object(self):
        """
        the network object to which belongs this ip address range.
        ``attribute type:`` model
        """
        return self.broker.device_object(**{"DeviceIPRangeID": self.DeviceIPRangeID})

    @property
    @check_api_availability
    def data_source(self):
        """
        The collector NetMRI that collected this data record.
        ``attribute type:`` model
        """
        return self.broker.data_source(**{"DeviceIPRangeID": self.DeviceIPRangeID})

    @property
    @check_api_availability
    def device(self):
        """
        The device from which this data was collected.
        ``attribute type:`` model
        """
        return self.broker.device(**{"DeviceIPRangeID": self.DeviceIPRangeID})



from ..remote import RemoteModel


class SwitchFwdNeighborRemote(RemoteModel):
    """
    Neighbor relationships between a device providing L2 switching and the peer device.


    |  ``DataSourceID:`` The internal NetMRI identifier for the collector NetMRI that collected this data record.
    |  ``attribute type:`` number

    |  ``NeighborID:`` The internal NetMRI identifier for the neighbor relationship. This can be used to look up the Neighbor relationship which contains the source and destination device information.
    |  ``attribute type:`` number

    |  ``SwitchFwdNeighborChangedCols:`` The fields that changed between this revision of the record and the previous revision.
    |  ``attribute type:`` string

    |  ``SwitchFwdNeighborEndTime:`` The ending effective time of this revision of this record, or empty if still in effect.
    |  ``attribute type:`` datetime

    |  ``SwitchFwdNeighborMAC:`` The Media Access Controller (MAC) address of the destination neighbor in this neighbor relationship.
    |  ``attribute type:`` string

    |  ``SwitchFwdNeighborMapSource:`` Internal tracking information for NetMRI algorithms.
    |  ``attribute type:`` string

    |  ``SwitchFwdNeighborStartTime:`` The starting effective time of this revision of the record.
    |  ``attribute type:`` datetime

    |  ``SwitchFwdNeighborTimestamp:`` The date and time this record was collected or calculated.
    |  ``attribute type:`` datetime

    |  ``SwitchFwdNeighborType:`` Internal tracking information for NetMRI algorithms.
    |  ``attribute type:`` string

    |  ``SwitchFwdNeighborIPDotted:`` The IP address corresponding to the MAC found in the switch forwarding table, in dotted (or colon-delimited for IPv6) format.
    |  ``attribute type:`` string

    |  ``SwitchFwdNeighborIPNumeric:`` The numerical value of the IP address corresponding to the MAC found in the switch forwarding table.
    |  ``attribute type:`` number

    |  ``SwitchFwdNeighborFirstSeenTime:`` The date and time this switch forwarding neighbor was first seen on the network, and since which it has been continuously present.
    |  ``attribute type:`` datetime

    |  ``SwitchFwdNeighborVlanID:`` The internal NetMRI identifier for the VLAN of this neighbor.
    |  ``attribute type:`` number

    |  ``SwitchFwdNeighborVlanIndex:`` The numerical VLAN number (VLAN ID) of this neighbor.
    |  ``attribute type:`` number

    |  ``network_name:`` The name of the Network View associated.
    |  ``attribute type:`` string

    """

    properties = ("DataSourceID",
                  "NeighborID",
                  "SwitchFwdNeighborChangedCols",
                  "SwitchFwdNeighborEndTime",
                  "SwitchFwdNeighborMAC",
                  "SwitchFwdNeighborMapSource",
                  "SwitchFwdNeighborStartTime",
                  "SwitchFwdNeighborTimestamp",
                  "SwitchFwdNeighborType",
                  "SwitchFwdNeighborIPDotted",
                  "SwitchFwdNeighborIPNumeric",
                  "SwitchFwdNeighborFirstSeenTime",
                  "SwitchFwdNeighborVlanID",
                  "SwitchFwdNeighborVlanIndex",
                  "network_name",
                  )



from ..remote import RemoteModel
from infoblox_netmri.utils.utils import check_api_availability


class DataCollectionStatusRemote(RemoteModel):
    """
    status and time of last collections


    |  ``DeviceID:`` The internal NetMRI identifier for the device on which collection applied.
    |  ``attribute type:`` number

    |  ``SystemInd:`` The indicator of collection of system information.
    |  ``attribute type:`` string

    |  ``CPUInd:`` The indicator of collection of cpu information.
    |  ``attribute type:`` string

    |  ``MemoryInd:`` The indicator of collection of memory information.
    |  ``attribute type:`` string

    |  ``VlansInd:`` The indicator of collection of virtual LAN information.
    |  ``attribute type:`` string

    |  ``ForwardingInd:`` The indicator of collection of forwarding information.
    |  ``attribute type:`` string

    |  ``EnvironmentalInd:`` The indicator of collection of environmental information.
    |  ``attribute type:`` string

    |  ``InventoryInd:`` The indicator of collection of the inventory information.
    |  ``attribute type:`` string

    |  ``ARPInd:`` The indicator of collection of the arp information.
    |  ``attribute type:`` string

    |  ``RouteInd:`` The indicator of collection of the route information.
    |  ``attribute type:`` string

    |  ``NeighborInd:`` The indicator of collection of the neighborhood information.
    |  ``attribute type:`` string

    |  ``ConfigInd:`` The indicator of collection of the configuration information.
    |  ``attribute type:`` string

    |  ``AccessInd:`` The indicator of collection of the filtering access information.
    |  ``attribute type:`` string

    |  ``SystemTimestamp:`` The date and time of last collect of the system information.
    |  ``attribute type:`` datetime

    |  ``CPUTimestamp:`` The date and time of last collect of the cpu information.
    |  ``attribute type:`` datetime

    |  ``MemoryTimestamp:`` The date and time of last collect of the memory information.
    |  ``attribute type:`` datetime

    |  ``VlansTimestamp:`` The date and time of last collect of the virtual LAN information.
    |  ``attribute type:`` datetime

    |  ``ForwardingTimestamp:`` The date and time of last collect of the forwarding information.
    |  ``attribute type:`` datetime

    |  ``EnvironmentalTimestamp:`` The date and time of last collect of the environmental information.
    |  ``attribute type:`` datetime

    |  ``InventoryTimestamp:`` The date and time of last collect of the inventory information.
    |  ``attribute type:`` datetime

    |  ``ARPTimestamp:`` The date and time of last collect of the arp information.
    |  ``attribute type:`` datetime

    |  ``RouteTimestamp:`` The date and time of last collect of the route information.
    |  ``attribute type:`` datetime

    |  ``NeighborTimestamp:`` The date and time of last collect of the neighborhood information.
    |  ``attribute type:`` datetime

    |  ``ConfigTimestamp:`` The date and time of last collect of the configuration information.
    |  ``attribute type:`` datetime

    |  ``AccessTimestamp:`` The date and time of last collect of the filtering access information.
    |  ``attribute type:`` datetime

    |  ``system:`` The indicator of collection of system information.
    |  ``attribute type:`` bool

    |  ``cpu:`` The indicator of collection of cpu information.
    |  ``attribute type:`` bool

    |  ``memory:`` The indicator of collection of memory information.
    |  ``attribute type:`` bool

    |  ``vlans:`` The indicator of collection of virtual LAN information.
    |  ``attribute type:`` bool

    |  ``forwarding:`` The indicator of collection of forwarding information.
    |  ``attribute type:`` bool

    |  ``environmental:`` The indicator of collection of environmental information.
    |  ``attribute type:`` bool

    |  ``inventory:`` The indicator of collection of the inventory information.
    |  ``attribute type:`` bool

    |  ``arp:`` The indicator of collection of the arp information.
    |  ``attribute type:`` bool

    |  ``route:`` The indicator of collection of the route information.
    |  ``attribute type:`` bool

    |  ``neighbor:`` The indicator of collection of the neighborhood information.
    |  ``attribute type:`` bool

    |  ``config:`` The indicator of collection of the configuration information.
    |  ``attribute type:`` bool

    |  ``access:`` The indicator of collection of the filtering access information.
    |  ``attribute type:`` bool


    |  ``VrfInd:`` The indicator of collection of virtual network information.
    |  ``attribute type:`` string

    |  ``VrfTimestamp:`` The date and time of last collect of the virtual network information.
    |  ``attribute type:`` datetime

    """

    properties = ("DeviceID",
                  "SystemInd",
                  "CPUInd",
                  "MemoryInd",
                  "VlansInd",
                  "ForwardingInd",
                  "EnvironmentalInd",
                  "InventoryInd",
                  "ARPInd",
                  "RouteInd",
                  "NeighborInd",
                  "ConfigInd",
                  "AccessInd",
                  "SystemTimestamp",
                  "CPUTimestamp",
                  "MemoryTimestamp",
                  "VlansTimestamp",
                  "ForwardingTimestamp",
                  "EnvironmentalTimestamp",
                  "InventoryTimestamp",
                  "ARPTimestamp",
                  "RouteTimestamp",
                  "NeighborTimestamp",
                  "ConfigTimestamp",
                  "AccessTimestamp",
                  "system",
                  "cpu",
                  "memory",
                  "vlans",
                  "forwarding",
                  "environmental",
                  "inventory",
                  "arp",
                  "route",
                  "neighbor",
                  "config",
                  "access",
                  "VrfInd",
                  "VrfTimestamp",
                  )

    @property
    @check_api_availability
    def device(self):
        """
        The device from which this data was collected.
        ``attribute type:`` model
        """
        return self.broker.device(**{"DeviceID": self.DeviceID})



from ..broker import Broker


class DiscoveryStatusesBroker(Broker):
    controller = "discovery_statuses"

    def check_withdrawal_license(self, **kwargs):
        """Check Management Server and Managed Devices when device unlicensed with SDC license

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: The list of devices to be checked
             :type DeviceIDs: Array

            **Outputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :return cascading_impact: Warning message for user
             :rtype cascading_impact: String

            """

        return self.api_request(self._get_method_fullname("check_withdrawal_license"), kwargs)

    def search(self, **kwargs):
        """Searches the current discovery statuses based on view

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` current

             :param view: Defined filters for displaying discovery statuses data. Valid values are "current", "non_reached", "problems". "ok"
             :type view: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param NetworkID: The NetworkID maps to one or more collectors that are identified by DataSourceIDs.
             :type NetworkID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_DeviceName: The operator to apply to the field DeviceName. DeviceName: The NetMRI name of the device; this will be either the same as DeviceSysName or DeviceDNSName, depending on your NetMRI configuration.
             :type op_DeviceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_DeviceName: If op_DeviceName is specified, this value will be compared to the value in DeviceName using the specified operator. The value in this input will be treated as an explicit constant value. This field must be specified if op_DeviceName is specified.
             :type val_c_DeviceName: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param op_IPAddress: The operator to apply to ip address fields like Device.DeviceIPDotted and ifAddr.IfIPDotted. DeviceIPDotted : The management IP address of the device, in dotted (or colon-delimited for IPv6) format. IfIPDotted: The IP address configured on the device in dotted (or colon-delimited for IPv6) format.
             :type op_IPAddress: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param val_c_IPAddress: If op_IPAddress is specified, this value will be compared to the value in IPAddress using the specified operator. The value in this input will be treated as an explicit constant value. This field must be specified if op_IPAddress is specified.
             :type val_c_IPAddress: String

            |  ``api version min:`` 2.10
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param management_ip_only_ind: If op_IPAddress is used, by default entire ip addresses is searched. Set the value in this input to true to search only management ip addresses.
             :type management_ip_only_ind: Boolean

            |  ``api version min:`` 3.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param select: The list of fields to return for each discovery status. Valid values are DeviceID, DeviceIPDotted, VirtualNetworkID, VirtualNetworkName, VirtualNetworkMemberArtificialInd, DeviceIPNumeric, DeviceName, DeviceType, DeviceUniqueKey, Status, StatusDetail, SPMLicensedInd, SAMLicensedInd, LicenseOverride, FirstSeen, DeviceFirstOccurrenceTime, LastSeen, FingerPrintEnabled, SDNCollectionEnabled, SNMPCollectionEnabled, CLICollectionEnabled, ConfigCollectionEnabled, CLICredentialMessage, CLICredentialStatus, CLICredentialTimestamp, GlobalConfigCollectionEnabled, GlobalConfigCollectionMessage, ConfigCollectionMessage, ConfigCollectionStatus, ConfigCollectionStatusSort, ConfigCollectionTimestamp, DeviceGroupMessage, DeviceGroupStatus, DeviceGroupTimestamp, ExistsMessage, ExistsTimestamp, FingerPrintMessage, FingerPrintStatus, FingerPrintTimestamp, SDNCollectionMessage, SDNCollectionStatus, SDNCollectionTimestamp, LastAction, LastTimestamp, ReachableMessage, ReachableStatus, ReachableTimestamp, SNMPCollectionMessage, SNMPCollectionStatus, SNMPCollectionTimestamp, SNMPCredentialMessage, SNMPCredentialStatus, SNMPCredentialTimestamp, RuleListAnalysisMessage, RuleListAnalysisStatus, RuleListAnalysisTimestamp, UnitID, AccessInd, ForwardingInd, StartPortControlBlackoutSchedule, PortControlBlackoutDuration, StartBlackoutSchedule, BlackoutDuration. If empty or omitted, all fields will be returned.
             :type select: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The index of the last row to display. Default value is 25
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param order: The sort order for the output.
             :type order: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param xml_filter: A SetFilter XML structure to further refine the search. The SetFilter will be applied AFTER any search query or field values, but before any limit options. The limit will not be enforced when this filter is used, and paging is not supported.
             :type xml_filter: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("search"), kwargs)

    def static(self, **kwargs):
        """Displays the current discovery statuses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` current

             :param view: Defined filters for displaying discovery statuses data. Valid values are "current", "licensed", "non_reached", "problems", "ok"
             :type view: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The index of the last row to display. Default value is 25
             :type limit: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param query: Search string
             :type query: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only. Specifying a UnitID will pull the most recent data from a specific collector while not specifying one will pull data directly from the OC.
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("static"), kwargs)

    def telnet_queue(self, **kwargs):
        """Displays the telnet queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("telnet_queue"), kwargs)

    def ssh_queue(self, **kwargs):
        """Displays the ssh queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("ssh_queue"), kwargs)

    def snmp_queue(self, **kwargs):
        """Displays the snmp queue

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param start: The index of the first row to display
             :type start: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 25

             :param limit: The maximum number of rows from the start to display
             :type limit: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("snmp_queue"), kwargs)

    def summary(self, **kwargs):
        """Summary data for discovery statuses

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("summary"), kwargs)

    def discover_next(self, **kwargs):
        """Set the given device ids to be discovered next

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: An array of device ids to be discovered next
             :type DeviceIDs: Array

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("discover_next"), kwargs)

    def discover_now(self, **kwargs):
        """Set the "DeviceID" of the given device to be discovered now and check the status of previously started discovery process. If the "id" parameter is not set, the method starts a new Discover Now process and returns its id for further tracking the process status. If the "id" parameter is set, the method returns a chunk of log output of the corresponding discovery process. The number of bytes to read is defined by the "read" parameter.

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param id: The id of the previously started discovery process required to retrieve its status
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param DeviceID: ID of the device to re-discover now, if known
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param ip_address: Device IP address to be discovered now
             :type ip_address: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param read: The number of bytes to read from the discover now output
             :type read: Integer

            |  ``api version min:`` 2.1.1
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` False

             :param ignore_history_ind: If true, NetMRI will not check for previous instances of this IP address, and therefore will not associate this IP address with the associated device history.
             :type ignore_history_ind: Boolean

            |  ``api version min:`` 2.4
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param mac_address: Device MAC address to be discovered now
             :type mac_address: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("discover_now"), kwargs)

    def abort_discovery(self, **kwargs):
        """Abort an outstanding discover now session

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param id: ID of the discover now request to abort
             :type id: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("abort_discovery"), kwargs)

    def override_licenses(self, **kwargs):
        """Overrides a license for all or some devices

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: The list of devices to override licenses
             :type DeviceIDs: Array

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param Licensed: The state of the device license override. Valid values are 0 (unlicensed), 1 (licensed), 2 (automatic)
             :type Licensed: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SwitchPortManagement: The state of the Switch Port Management license override. Valid values are on or off if exists. An empty string is passed if not present.
             :type SwitchPortManagement: String

            |  ``api version min:`` 2.6
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param AccessProvisioning: The state of the Security Device Controller license override. Valid values are on or off if exists. An empty string is passed if not present.
             :type AccessProvisioning: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("override_licenses"), kwargs)

    def unmanage(self, **kwargs):
        """Set one or more specified devices to unmanaged

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceIDs: The list of devices to set to unmanaged
             :type DeviceIDs: Array

            |  ``api version min:`` 2.8
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` 0

             :param UnitID: ID of the collector to send the request to, OC only
             :type UnitID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("unmanage"), kwargs)

    def update_snmp(self, **kwargs):
        """Update the SNMP read credential for a device

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to be updated
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param SNMPVersion: The SNMP Version
             :type SNMPVersion: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPRead: The SNMP read community
             :type SNMPRead: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPAuthPW: The SNMP auth password for SNMPv3
             :type SNMPAuthPW: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPAuthProto: The SNMP auth protocol for SNMPv3
             :type SNMPAuthProto: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPPrivPW: The SNMP priv password for SNMPv3
             :type SNMPPrivPW: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param SNMPPrivProto: The SNMP priv protocol for SNMPv3
             :type SNMPPrivProto: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("update_snmp"), kwargs)

    def update_cli_credentials(self, **kwargs):
        """Update the CLI credential for a device

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to be updated
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.SSH.Username: SSH username
             :type config.SSH.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.SSH.Password: SSH password
             :type config.SSH.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.Telnet.Username: Telnet username
             :type config.Telnet.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.Telnet.Password: Telnet password
             :type config.Telnet.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.HTTP.Username: HTTP username
             :type config.HTTP.Username: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.HTTP.Password: HTTP password
             :type config.HTTP.Password: String

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param config.EnablePassword: Enable password
             :type config.EnablePassword: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("update_cli_credentials"), kwargs)

    def cli_guesses(self, **kwargs):
        """Displays the status of all devices CLI guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("cli_guesses"), kwargs)

    def snmp_guesses(self, **kwargs):
        """Displays the status of all devices SNMP guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("snmp_guesses"), kwargs)

    def show_opsec_certificate(self, **kwargs):
        """Return OPSEC device certificate

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("show_opsec_certificate"), kwargs)

    def opsec_guesses(self, **kwargs):
        """Displays the status of all devices OPSEC guesses

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device
             :type DeviceID: Integer

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` False
            |  ``default:`` None

             :param filename: Filename for exported data
             :type filename: String

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("opsec_guesses"), kwargs)

    def status_management(self, **kwargs):
        """Returns a list of discovery statuses of the device with given id

            **Inputs**

            |  ``api version min:`` None
            |  ``api version max:`` None
            |  ``required:`` True
            |  ``default:`` None

             :param DeviceID: The id of the device to get management status
             :type DeviceID: Integer

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("status_management"), kwargs)

    def setup_summary(self, **kwargs):
        """Discovery Wizard setup summary information

            **Inputs**

            **Outputs**

            """

        return self.api_request(self._get_method_fullname("setup_summary"), kwargs)
